#
# spec file for package apache-commons-validator
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define short_name commons-validator
Name:           apache-%{short_name}
Version:        1.3.1
Release:        bp154.1.34
Summary:        Apache Commons Validator
License:        Apache-2.0
Group:          Development/Libraries/Java
Url:            http://commons.apache.org/commons/
Source0:        %{short_name}-%{version}-src.tar.gz
Patch0:         commons-validator-1.3.1-crosslink.patch
# https://issues.apache.org/jira/browse/VALIDATOR-303
Patch1:         commons-validator-1.3.1-srcencoding.patch
Patch2:         commons-validator-1.3.1-locale.patch
BuildRequires:  ant
BuildRequires:  apache-commons-beanutils
BuildRequires:  apache-commons-collections
BuildRequires:  apache-commons-logging
BuildRequires:  fdupes
BuildRequires:  jakarta-commons-digester
BuildRequires:  java-devel
BuildRequires:  junit
BuildRequires:  oro
Requires:       apache-commons-beanutils >= 1.5
Requires:       apache-commons-collections
Requires:       apache-commons-logging >= 1.0.2
Requires:       jakarta-commons-digester >= 1.3
Requires:       oro >= 2.0.6
Provides:       %{short_name} = %{version}-%{release}
Obsoletes:      %{short_name} < %{version}-%{release}
Provides:       jakarta-%{short_name} = %{version}-%{release}
Obsoletes:      jakarta-%{short_name} < %{version}-%{release}
BuildArch:      noarch
%if 0%{?suse_version} == 1110
BuildRequires:  ant-apache-oro
Requires:       ant-apache-oro
%endif

%description
A common issue when receiving data either electronically or from user
input is verifying the integrity of the data. This work is repetitive
and becomes even more complicated when different sets of validation
rules need to be applied to the same set of data based, for example, on
locale. Error messages may also vary by locale. This package attempts
to address some of these issues and speed development and maintenance
of validation rules.

%package javadoc
Summary:        Javadoc for jakarta-commons-validator
Group:          Development/Libraries/Java
Requires(pre):  coreutils

%description javadoc
A common issue when receiving data either electronically or from user
input is verifying the integrity of the data. This work is repetitive
and becomes even more complicated when different sets of validation
rules need to be applied to the same set of data based on locale for
example. Error messages may also vary by locale. This package attempts
to address some of these issues and speed development and maintenance
of validation rules.

This package contains the javadoc documentation for the Jakarta Commons
Validator Package.

%prep
%setup -q -n %{short_name}-%{version}-src
%patch0 -p1
%patch1 -p1
%patch2 -p1

sed -i 's/\r//' LICENSE.txt
sed -i 's/\r//' RELEASE-NOTES.txt
sed -i 's/\r//' NOTICE.txt

# use textui instead of awtui (not available in junit4+)
sed -i 's:junit.awtui.TestRunner.main:junit.textui.TestRunner.main:g' \
        src/test/org/apache/commons/validator/*java

%build
export CLASSPATH=$(build-classpath \
                   commons-collections \
                   commons-logging \
                   commons-digester \
                   commons-beanutils \
                   junit \
                   jakarta-oro )
ant \
    -Dcompile.source=1.6 -Dcompile.target=1.6 \
    -Dskip.download=true -Dbuild.sysclasspath=first \
    dist

%check
export CLASSPATH=$(build-classpath \
                   commons-collections \
                   commons-logging \
                   commons-digester \
                   commons-beanutils \
                   junit \
                   jakarta-oro )
ant \
    -Dcompile.source=1.6 -Dcompile.target=1.6 \
    -Dant.build.javac.source=1.6 -Dant.build.javac.target=1.6 \
    -Dskip.download=true -Dbuild.sysclasspath=first \
    test

%install

# jars
install -d -m 0755 %{buildroot}%{_javadir}
install -pm 644 dist/%{short_name}-%{version}.jar %{buildroot}%{_javadir}/%{name}.jar
ln -s %{name}.jar %{buildroot}%{_javadir}/%{short_name}.jar

# javadoc
install -d -m 0755 %{buildroot}%{_javadocdir}/%{name}
cp -pr dist/docs/api*/* %{buildroot}%{_javadocdir}/%{name}/
%fdupes -s %{buildroot}%{_javadocdir}/%{name}/

%files
%doc LICENSE.txt NOTICE.txt RELEASE-NOTES.txt
%{_javadir}/%{name}.jar
%{_javadir}/%{short_name}.jar

%files javadoc
%doc LICENSE.txt
%doc %{_javadocdir}/%{name}

%changelog
* Mon Oct  9 2017 fstrba@suse.com
- Fix build and running of junit tests with Java 9+
- Added patch:
  * commons-validator-1.3.1-locale.patch
    + Made two different test.routines target, one with java <= 1.8
    and one with java 9+, since the locale providers changed
    between java 1.8 and 9. Moreover, the options that Java 9
    needs to run in compatibility mode break build with lower
    versions of Java.
* Thu Sep 14 2017 fstrba@suse.com
- Build with java source and target 1.6
- Use java-devel < 1.9 because with jdk9, some unit tests fail
- Clean spec file
* Tue Jul  8 2014 tchvatal@suse.com
- Cleanup with spec-cleaner and fix build on Factory.
* Mon Apr 14 2014 darin@darins.net
- add requirements for SLES
* Fri Jun 15 2012 mvyskocil@suse.cz
- update to 1.3.1
- rename to apache-commons-validator
* Mon Sep 25 2006 skh@suse.de
- don't use icecream
- use source="1.4" and target="1.4" for build with java 1.5
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jul 28 2005 jsmeix@suse.de
- Current version 1.1.4 from JPackage.org
* Mon Jul 18 2005 jsmeix@suse.de
- Current version 1.1.3 from JPackage.org
* Tue Feb 22 2005 skh@suse.de
- Update to version 1.1.3
* Sun Sep  5 2004 skh@suse.de
- Initial package created with version 1.0.2 (Jakarta 1.5)
